@@ -1,5 +1,7 @@
 """
-Main interface for machinelearning service client paginators.
+Type annotations for machinelearning service client paginators.
+
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_machinelearning/paginators.html)
 
 Usage::
 
@@ -51,7 +53,7 @@ __all__ = (
 
 class DescribeBatchPredictionsPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeBatchPredictions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeBatchPredictions)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.64/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeBatchPredictions)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_machinelearning/paginators.html#describebatchpredictionspaginator)
     """
 
     def paginate(
@@ -68,13 +70,14 @@ class DescribeBatchPredictionsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[DescribeBatchPredictionsOutputTypeDef]:
         """
-        [DescribeBatchPredictions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeBatchPredictions.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.64/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeBatchPredictions.paginate)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_machinelearning/paginators.html#describebatchpredictionspaginator)
         """
 
 
 class DescribeDataSourcesPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeDataSources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeDataSources)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.64/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeDataSources)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_machinelearning/paginators.html#describedatasourcespaginator)
     """
 
     def paginate(
@@ -91,13 +94,14 @@ class DescribeDataSourcesPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[DescribeDataSourcesOutputTypeDef]:
         """
-        [DescribeDataSources.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeDataSources.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.64/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeDataSources.paginate)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_machinelearning/paginators.html#describedatasourcespaginator)
         """
 
 
 class DescribeEvaluationsPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeEvaluations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeEvaluations)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.64/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeEvaluations)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_machinelearning/paginators.html#describeevaluationspaginator)
     """
 
     def paginate(
@@ -114,13 +118,14 @@ class DescribeEvaluationsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[DescribeEvaluationsOutputTypeDef]:
         """
-        [DescribeEvaluations.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeEvaluations.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.64/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeEvaluations.paginate)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_machinelearning/paginators.html#describeevaluationspaginator)
         """
 
 
 class DescribeMLModelsPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeMLModels documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeMLModels)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.64/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeMLModels)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_machinelearning/paginators.html#describemlmodelspaginator)
     """
 
     def paginate(
@@ -137,5 +142,6 @@ class DescribeMLModelsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[DescribeMLModelsOutputTypeDef]:
         """
-        [DescribeMLModels.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeMLModels.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.64/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeMLModels.paginate)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_machinelearning/paginators.html#describemlmodelspaginator)
         """
